@@ -18,7 +18,7 @@ class EventMiddleware(MiddlewareMixin):
 
     def process_response(self, request, response):
         try:
-            if response.status_code < 300 and request.method != 'GET':
+            if response.status_code < 300 and response.status_code >= 200 and request.method != 'GET':
                 data = self.parsing(request, response)
                 if data:
                     self.q.put(data)
