@@ -7,6 +7,7 @@ class BaseArgsParsing:
     DESC = "desc"
     TOKEN = 'token'
     IGNORE_CREATOR = 'ignore_creator'
+    ALL_RESULT = 'all_result'
 
     LIKE = "like"
     NOT = "not"
@@ -16,7 +17,7 @@ class BaseArgsParsing:
     LTE = "lte"
     GTE = "gte"
 
-    RESERVED_FIELD = [PAGE, SIZE, PAGESIZE, SORT, TOKEN, IGNORE_CREATOR]
+    RESERVED_FIELD = [PAGE, SIZE, PAGESIZE, SORT, TOKEN, IGNORE_CREATOR, ALL_RESULT]
     SUFFIX_KEYWORD = [LIKE, NOT, IN, LT, GT, LTE, GTE]
 
     def get_page_and_size(self, data, max_page=500, max_size=1000, max_total=10000):
