@@ -116,7 +116,7 @@ class BaseTenantRole(models.Model):
         db_table = "tenant_role"
         abstract = True
 
-    tenant = models.ForeignKey(to=Tenant, to_field="account", null=True, on_delete=models.SET_NULL)
+    tenant = models.ForeignKey(to=Tenant, to_field="account", null=True, on_delete=models.SET_NULL, unique=True)
     role = models.ForeignKey(to=Role, to_field="name", on_delete=models.SET_NULL, null=True)
 
 
